@@ -74,9 +74,11 @@ import org.apache.openmeetings.util.StoredFile;
 import org.apache.wicket.util.string.Strings;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
-import org.springframework.beans.factory.annotation.Autowired;
+
 import org.springframework.stereotype.Component;
 
+import jakarta.inject.Inject;
+
 /**
  * Management of optional LDAP Login
  *
@@ -134,13 +136,14 @@ public class LdapLoginManager {
 		, ATTRIBUTE
 		, QUERY
 	}
-	@Autowired
+
+	@Inject
 	private LdapConfigDao ldapConfigDao;
-	@Autowired
+	@Inject
 	private UserDao userDao;
-	@Autowired
+	@Inject
 	private GroupDao groupDao;
-	@Autowired
+	@Inject
 	private ImageConverter imageConverter;
 
 	private static void bindAdmin(LdapConnection conn, LdapOptions options) throws LdapException {
@@ -349,13 +352,13 @@ public class LdapLoginManager {
 			conn = new LdapNetworkConnection(options.host, options.port, options.secure);
 		}
 
-		private User updatePic(User inUser, InputStream is, StoredFile sf) {
+		private User updatePic(User inUser, InputStream is) {
 			User u = inUser;
 			Path tempImage = null;
 			try {
 				tempImage = Files.createTempFile("omLdap", "img");
 				FileUtils.copyToFile(is, tempImage.toFile());
-				imageConverter.convertImageUserProfile(tempImage.toFile(), inUser.getId(), sf.isAsIs());
+				imageConverter.convertImageUserProfile(tempImage.toFile(), inUser.getId());
 				u = userDao.get(inUser.getId());
 			} catch (Exception e) {
 				log.error("Unable to store binary image from LDAP", e);
@@ -380,7 +383,7 @@ public class LdapLoginManager {
 						InputStream is = new ByteArrayInputStream(val.getBytes());
 						StoredFile sf = new StoredFile("picture", is);
 						if (sf.isImage()) {
-							u = updatePic(inUser, is, sf);
+							u = updatePic(inUser, is);
 						} else {
 							u.setPictureUri(val.getString());
 						}
