@@ -19,22 +19,23 @@
 package org.apache.openmeetings.web;
 
 import static java.util.UUID.randomUUID;
+import static java.time.format.DateTimeFormatter.ISO_OFFSET_DATE_TIME;
+import static java.time.ZoneOffset.UTC;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertNotNull;
 
 import java.time.LocalDateTime;
 import java.util.List;
 
-import org.apache.openmeetings.AbstractWicketTesterTest;
 import org.apache.openmeetings.db.entity.calendar.Appointment;
 import org.apache.openmeetings.db.entity.user.User;
-import org.apache.openmeetings.util.OmException;
 import org.apache.openmeetings.web.user.calendar.CalendarPanel;
+import org.apache.openmeetings.util.OmException;
 import org.apache.wicket.behavior.AbstractAjaxBehavior;
 import org.apache.wicket.util.tester.FormTester;
 import org.junit.jupiter.api.Test;
 
-import com.googlecode.wicket.jquery.ui.calendar.CalendarView;
+import org.wicketstuff.jquery.ui.calendar6.CalendarView;
 
 import de.agilecoders.wicket.core.markup.html.bootstrap.navbar.Navbar;
 
@@ -47,7 +48,7 @@ class TestCalendar extends AbstractWicketTesterTest {
 		testArea(regularUsername, p -> {
 			Navbar menu = (Navbar)p.get(PATH_MENU);
 			assertNotNull(menu);
-			tester.executeBehavior((AbstractAjaxBehavior)menu.get("collapse:navLeftListEnclosure:navLeftList:0:component:dropdown-menu:buttons:1:button").getBehaviorById(0));
+			tester.executeBehavior((AbstractAjaxBehavior)menu.get("container:collapse:navLeftListEnclosure:navLeftList:0:component:dropdown-menu:buttons:1:button").getBehaviorById(0));
 
 			tester.assertComponent(PATH_CHILD, CalendarPanel.class);
 			CalendarPanel cal = (CalendarPanel)p.get(PATH_CHILD);
@@ -56,13 +57,13 @@ class TestCalendar extends AbstractWicketTesterTest {
 			User u = userDao.getByLogin(regularUsername, User.Type.USER, null);
 			//test create month
 			tester.getRequest().setParameter("allDay", String.valueOf(false));
-			tester.getRequest().setParameter("startDate", LocalDateTime.of(2017, 11, 13, 13, 13).toString());
-			tester.getRequest().setParameter("endDate", LocalDateTime.of(2017, 11, 13, 13, 13).toString());
-			tester.getRequest().setParameter("viewName", CalendarView.month.name());
+			tester.getRequest().setParameter("startDate", LocalDateTime.of(2017, 11, 13, 13, 13).atOffset(UTC).format(ISO_OFFSET_DATE_TIME));
+			tester.getRequest().setParameter("endDate", LocalDateTime.of(2017, 11, 13, 13, 13).atOffset(UTC).format(ISO_OFFSET_DATE_TIME));
+			tester.getRequest().setParameter("viewName", CalendarView.dayGridMonth.name());
 			tester.executeBehavior((AbstractAjaxBehavior)cal.get("form:calendar").getBehaviorById(0)); //select-event
 			FormTester appTester = tester.newFormTester(PATH_APPOINTMENT_DLG_FRM);
 			//check inviteeType:groupContainer:groups is invisible for regular user
-			String title = String.format("title%s", randomUUID());
+			String title = "title" + randomUUID();
 			appTester.setValue("title", title);
 			AbstractAjaxBehavior save = getButtonBehavior(PATH_APPOINTMENT_DLG, 0);
 			tester.executeBehavior(save);
