@@ -20,9 +20,9 @@ package org.apache.openmeetings.webservice;
 
 import static java.nio.charset.StandardCharsets.UTF_8;
 import static java.util.UUID.randomUUID;
-import static org.apache.openmeetings.AbstractOmServerTest.UNIT_TEST_ARAB_EXT_TYPE;
-import static org.apache.openmeetings.AbstractOmServerTest.createUser;
-import static org.apache.openmeetings.AbstractOmServerTest.getUser;
+import static org.apache.openmeetings.web.AbstractOmServerTest.UNIT_TEST_ARAB_EXT_TYPE;
+import static org.apache.openmeetings.web.AbstractOmServerTest.createUser;
+import static org.apache.openmeetings.web.AbstractOmServerTest.getUser;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertNotNull;
@@ -31,6 +31,7 @@ import java.awt.Graphics;
 import java.awt.image.BufferedImage;
 import java.io.File;
 import java.io.IOException;
+import java.nio.file.Files;
 import java.util.Collection;
 
 import javax.imageio.ImageIO;
@@ -67,8 +68,8 @@ class TestFileService extends AbstractWebServiceTest {
 			assertEquals(width, cr.getObj().getWidth(), "Width should be determined");
 			assertEquals(height, cr.getObj().getHeight(), "Height should be Image");
 		} finally {
-			if (img != null && img.exists()) {
-				img.delete();
+			if (img != null) {
+				Files.deleteIfExists(img.toPath());
 			}
 		}
 	}
@@ -97,7 +98,8 @@ class TestFileService extends AbstractWebServiceTest {
 		f.setName("Arab external test");
 		f.setType(BaseFileItem.Type.IMAGE);
 		f.setInsertedBy(u.getId());
-		f = getBean(FileItemDao.class).update(f);
+		getBean(FileItemDao.class).update(f);
+
 		ServiceResult r = login();
 		Collection<? extends FileItemDTO> list = getClient(getFileUrl())
 				.path("/" + UrlEncoder.PATH_INSTANCE.encode(UNIT_TEST_ARAB_EXT_TYPE, UTF_8))
